@@ -11,24 +11,28 @@
    This file is part of the GNUstep GUI Library.
 
    This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
+   modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public
+   You should have received a copy of the GNU Lesser General Public
    License along with this library; see the file COPYING.LIB.
-   If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   If not, see <http://www.gnu.org/licenses/> or write to the 
+   Free Software Foundation, 51 Franklin Street, Fifth Floor, 
+   Boston, MA 02110-1301, USA.
 */
+
 #ifndef _GNUstep_H_GSInfoPanel
 #define _GNUstep_H_GSInfoPanel
 
-#include <AppKit/NSPanel.h>
+#import <AppKit/NSPanel.h>
+
+@class NSDictionary;
 
 /* If you need an Info Panel, the simpler thing to do is to use
  * NSApplication -orderFrontStandardInfoPanel: and 
@@ -36,7 +40,7 @@
  * They automatically manage an infoPanel for you.
  */
 
-@interface GSInfoPanel:NSPanel
+@interface GSInfoPanel: NSPanel
 {
 }
 /*
