@@ -3,7 +3,7 @@
 
    Main include file for GNUstep GUI Library
 
-   Copyright (C) 1996 Free Software Foundation, Inc.
+   Copyright (C) 1996-2015 Free Software Foundation, Inc.
 
    Author:  Scott Christley <scottc@net-community.com>
    Date: 1996
@@ -44,7 +44,10 @@
 //
 #import <AppKit/NSGraphics.h>
 
+#import <AppKit/NSAccessibility.h>
+#import <AppKit/NSAccessibilityConstants.h>
 #import <AppKit/NSActionCell.h>
+#import <AppKit/NSAnimationContext.h>
 #import <AppKit/NSApplication.h>
 #import <AppKit/NSAttributedString.h>
 #import <AppKit/NSBitmapImageRep.h>
@@ -93,6 +96,7 @@
 #import <AppKit/NSPageLayout.h>
 #import <AppKit/NSPanel.h>
 #import <AppKit/NSPasteboard.h>
+#import <AppKit/NSPasteboardItem.h>
 #import <AppKit/NSPopover.h>
 #import <AppKit/NSPopUpButton.h>
 #import <AppKit/NSPopUpButtonCell.h>
@@ -101,11 +105,13 @@
 #import <AppKit/NSPrintOperation.h>
 #import <AppKit/NSPrintPanel.h>
 #import <AppKit/NSResponder.h>
+#import <AppKit/NSRunningApplication.h>
 #import <AppKit/NSSavePanel.h>
 #import <AppKit/NSScreen.h>
 #import <AppKit/NSScroller.h>
 #import <AppKit/NSScrollView.h>
 #import <AppKit/NSSelection.h>
+#import <AppKit/NSSharingService.h>
 #import <AppKit/NSSlider.h>
 #import <AppKit/NSSliderCell.h>
 #import <AppKit/NSSpellChecker.h>
@@ -136,6 +142,8 @@
 #import <AppKit/NSDrawer.h>
 #import <AppKit/NSFileWrapper.h>
 #import <AppKit/NSFontDescriptor.h>
+#import <AppKit/NSGestureRecognizer.h>
+#import <AppKit/NSGlyphGenerator.h>
 #import <AppKit/NSGradient.h>
 #import <AppKit/NSGraphicsContext.h>
 #import <AppKit/NSHelpManager.h>
@@ -174,20 +182,27 @@
 #import <AppKit/NSTableView.h>
 #import <AppKit/NSTabView.h>
 #import <AppKit/NSTabViewItem.h>
+#import <AppKit/NSTextAlternatives.h>
 #import <AppKit/NSTextAttachment.h>
 #import <AppKit/NSTextContainer.h>
 #import <AppKit/NSTextList.h>
 #import <AppKit/NSTextStorage.h>
 #import <AppKit/NSTextTable.h>
 #import <AppKit/NSTextView.h>
+#import <AppKit/NSTokenField.h>
+#import <AppKit/NSTokenFieldCell.h>
 #import <AppKit/NSToolbar.h>
 #import <AppKit/NSToolbarItem.h>
+#import <AppKit/NSToolbarItemGroup.h>
 #import <AppKit/NSTrackingArea.h>
 #import <AppKit/NSTreeController.h>
 #import <AppKit/NSTreeNode.h>
 #import <AppKit/NSUserDefaultsController.h>
+#import <AppKit/NSUserInterfaceItemIdentification.h>
+#import <AppKit/NSUserInterfaceLayout.h>
 #import <AppKit/NSUserInterfaceValidation.h>
 #import <AppKit/NSViewController.h>
+#import <AppKit/NSVisualEffectView.h>
 #import <AppKit/NSWindowController.h>
 #endif
 
