@@ -41,6 +41,7 @@
 #import <AppKit/NSText.h>
 // for NSFocusRingType
 #import <AppKit/NSView.h>
+#import <AppKit/NSUserInterfaceLayout.h>
 
 @class NSString;
 @class NSMutableDictionary;
@@ -146,6 +147,15 @@ enum {
 };
 typedef NSUInteger NSImageScaling;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+enum {
+  NSCellHitNone = 0,
+  NSCellHitContentArea = 1,
+  NSCellHitEditableTextArea = 2,
+  NSCellHitTrackableArea = 4
+};
+#endif
+
 @interface NSCell : NSObject <NSCopying, NSCoding>
 {
   // Attributes
@@ -269,6 +279,15 @@ typedef NSUInteger NSImageScaling;
 - (void)setFocusRingType:(NSFocusRingType)type;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_8, GS_API_LATEST)
+#if GS_HAS_DECLARED_PROPERTIES
+@property NSUserInterfaceLayoutDirection userInterfaceLayoutDirection;
+#else
+- (NSUserInterfaceLayoutDirection) userInterfaceLayoutDirection;
+- (void) setUserInterfaceLayoutDirection: (NSUserInterfaceLayoutDirection)dir;
+#endif
+#endif
+
 //
 // Setting the NSCell's State 
 //
@@ -429,6 +448,11 @@ typedef NSUInteger NSImageScaling;
 	    inRect:(NSRect)cellFrame
 	    ofView:(NSView *)controlView
 	    untilMouseUp:(BOOL)flag;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (NSUInteger)hitTestForEvent:(NSEvent *)event
+                       inRect:(NSRect)cellFrame
+                       ofView:(NSView *)controlView;
+#endif
 
 //
 // Managing the Cursor 
