@@ -37,18 +37,30 @@
 @class NSPasteboard;
 @class NSImage;
 @class NSURL;
+@class NSDraggingSession;
 
-typedef enum _NSDragOperation {
+enum _NSDragOperation {
   NSDragOperationNone = 0,
   NSDragOperationCopy = 1,
   NSDragOperationLink = 2,
   NSDragOperationGeneric = 4,
   NSDragOperationPrivate = 8,
+  NSDragOperationAll = 15,
   NSDragOperationMove = 16,
   NSDragOperationDelete = 32,
-  NSDragOperationAll = 63,
-  NSDragOperationEvery = 0xffff  
-} NSDragOperation;
+  NSDragOperationEvery = UINT_MAX  
+};
+
+typedef NSUInteger NSDragOperation;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+typedef NSInteger NSDraggingContext;
+enum
+{
+  NSDraggingContextOutsideApplication = 0,
+  NSDraggingContextWithinApplication
+};
+#endif
 
 @protocol NSDraggingInfo
 
@@ -58,9 +70,9 @@ typedef enum _NSDragOperation {
 - (NSWindow *)draggingDestinationWindow;
 - (NSPoint)draggingLocation;
 - (NSPasteboard *)draggingPasteboard;
-- (int)draggingSequenceNumber;
+- (NSInteger)draggingSequenceNumber;
 - (id)draggingSource;
-- (unsigned int)draggingSourceOperationMask;
+- (NSDragOperation)draggingSourceOperationMask;
 
 //
 // Image Information
@@ -102,12 +114,35 @@ typedef enum _NSDragOperation {
 #endif
 @end
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+@protocol NSDraggingSource <NSObject>
+- (NSDragOperation) draggingSession:(NSDraggingSession *)session
+sourceOperationMaskForDraggingContext:(NSDraggingContext)context;
+
+#if GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
+@interface NSObject (NSDraggingSource107)
+#endif
+- (void) draggingSession: (NSDraggingSession *)session
+        willBeginAtPoint: (NSPoint)screenPoint;
+- (void) draggingSession: (NSDraggingSession *)session
+            movedToPoint: (NSPoint)screenPoint;
+- (void) draggingSession: (NSDraggingSession *)session
+            endedAtPoint: (NSPoint)screenPoint
+               operation: (NSDragOperation)operation;
+
+- (BOOL) ignoreModifierKeysForDraggingSession:(NSDraggingSession *)session;
+@end
+#endif
+
 @interface NSObject (NSDraggingSource)
 
 //
 // Querying the Source
 //
-- (unsigned int)draggingSourceOperationMaskForLocal:(BOOL)isLocal;
+- (NSDragOperation)draggingSourceOperationMaskForLocal:(BOOL)isLocal;
 - (BOOL)ignoreModifierKeysWhileDragging;
 
 //
