@@ -43,8 +43,9 @@
 #define _GNUstep_H_NSNib
 #import <GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSZone.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSZone.h>
+#import <AppKit/AppKitDefines.h>
 
 @class NSData;
 @class NSDictionary;
@@ -54,11 +55,17 @@
 @class NSArray;
 @class NSMutableArray;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+APPKIT_EXPORT NSString *NSNibTopLevelObjects;
+APPKIT_EXPORT NSString *NSNibOwner;
+#endif
+
 @interface NSNib : NSObject <NSCoding>
 {
   NSData *_nibData;
   id _loader;
   NSURL *_url;
+  NSBundle *_bundle;
 }
 
 // reading the data...
