@@ -304,7 +304,7 @@
     {
       NSToolbarItem *item = [toolbar _toolbarItemForIdentifier: identifier
 				     willBeInsertedIntoToolbar: NO];
-      NSLog(@"item %@ for ident %@", item, identifier);
+      NSDebugLLog(DEBUG_LEVEL, @"item %@ for ident %@", item, identifier);
       [_allowedItems addObject: item]; 
     }
 
