@@ -54,6 +54,10 @@ static NSString *alternateKeyString = @"+";
 static NSString *shiftKeyString = @"/";
 static NSString *commandKeyString = @"#";
 
+@interface NSMenuItemCell (Private)
+- (GSThemeControlState) themeControlState;
+@end
+
 @implementation NSMenuItemCell
 
 + (void) initialize
@@ -268,7 +272,7 @@ static NSString *commandKeyString = @"#";
 {
   NSSize   componentSize;
   NSImage *anImage = nil;
-  float    neededMenuItemHeight = 20;
+  CGFloat  neededMenuItemHeight = 20;
  
   // Check if _mcell_belongs_to_popupbutton = NO while cell owned by 
   // popup button. FIXME
@@ -385,7 +389,7 @@ static NSString *commandKeyString = @"#";
   return _needs_display;
 }
 
-- (float) imageWidth
+- (CGFloat) imageWidth
 {
   if (_needs_sizing)
     [self calcSize];
@@ -393,7 +397,7 @@ static NSString *commandKeyString = @"#";
   return _imageWidth;
 }
 
-- (float) titleWidth
+- (CGFloat) titleWidth
 {
   if (_needs_sizing)
     [self calcSize];
@@ -401,7 +405,7 @@ static NSString *commandKeyString = @"#";
   return _titleWidth;
 }
 
-- (float) keyEquivalentWidth
+- (CGFloat) keyEquivalentWidth
 {
   if (_needs_sizing)
     [self calcSize];
@@ -409,7 +413,7 @@ static NSString *commandKeyString = @"#";
   return _keyEquivalentWidth;
 }
 
-- (float) stateImageWidth
+- (CGFloat) stateImageWidth
 {
   if (_needs_sizing)
     [self calcSize];
@@ -526,6 +530,14 @@ static NSString *commandKeyString = @"#";
   if (_needs_sizing)
     [self calcSize];
 
+  if (_mcell_belongs_to_popupbutton && _cell.image_position)
+    {
+      // Special case: draw image on the extreme right 
+      cellFrame.origin.x  += [_menuView imageAndTitleOffset];
+      cellFrame.size.width = _titleWidth;
+      return cellFrame;
+    }
+
   if ([_menuView isHorizontal] == YES)
     {
       /* This adjust will center us within the menubar. */
@@ -565,7 +577,7 @@ static NSString *commandKeyString = @"#";
     {
       // Calculate the image part of cell frame from NSMenuView
       cellFrame.origin.x  += [_menuView imageAndTitleOffset];
-      cellFrame.size.width = [_menuView imageAndTitleWidth];
+      cellFrame.size.width = cellFrame.size.width - [_menuView imageAndTitleOffset];
 
       switch (_cell.image_position)
         {
@@ -579,11 +591,11 @@ static NSString *commandKeyString = @"#";
 
           case NSImageLeft:
             cellFrame.origin.x  += _imageWidth + GSCellTextImageXDist;
-            cellFrame.size.width = _titleWidth;
+            cellFrame.size.width = cellFrame.size.width - (_imageWidth + GSCellTextImageXDist);
             break;
 
           case NSImageRight:
-            cellFrame.size.width = _titleWidth;
+            cellFrame.size.width = cellFrame.size.width - (_imageWidth + GSCellTextImageXDist);
             break;
 
           case NSImageBelow:
@@ -617,7 +629,7 @@ static NSString *commandKeyString = @"#";
     {
       if (_cell.is_bordered)
         {
-          float yDelta = [_control_view isFlipped] ? 1. : 2.;
+          CGFloat yDelta = [_control_view isFlipped] ? 1. : 2.;
           unsigned mask;
           NSRect interiorFrame;
           
@@ -658,43 +670,6 @@ static NSString *commandKeyString = @"#";
     }
 }
 
-- (GSThemeControlState) themeControlState
-{
-  unsigned mask;
-  GSThemeControlState state = GSThemeNormalState;
-
-  // set the mask
-  if (_cell.is_highlighted)
-    {
-      mask = _highlightsByMask;
-      if (_cell.state)
-        {
-          mask &= ~_showAltStateMask;
-        }
-    }
-  else if (_cell.state)
-    mask = _showAltStateMask;
-  else
-    mask = NSNoCellMask;
-
-  /* Determine the background color. 
-     We draw when there is a border or when highlightsByMask
-     is NSChangeBackgroundCellMask or NSChangeGrayCellMask,
-     as required by our nextstep-like look and feel.  */
-  if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
-    {
-      state = GSThemeHighlightedState;
-    }
-
-  /* Pushed in buttons contents are displaced to the bottom right 1px.  */
-  if (mask & NSPushInCellMask)
-    {
-      state = GSThemeSelectedState;
-    }
-
-  return state;
-}
-
 //
 // Drawing.
 //
@@ -718,7 +693,17 @@ static NSString *commandKeyString = @"#";
 - (void) drawKeyEquivalentWithFrame: (NSRect)cellFrame
 			     inView: (NSView *)controlView
 {
-  NSImage	*arrow = [NSImage imageNamed: @"NSMenuArrow"];
+  NSImage	*arrow = nil;
+  if (_cell.is_highlighted)
+    {
+      arrow = [NSImage imageNamed: @"NSHighlightedMenuArrow"];
+    }
+
+  if (arrow == nil)
+    {
+      arrow = [NSImage imageNamed: @"NSMenuArrow"];
+    }
+
 
   cellFrame = [self keyEquivalentRectForBounds: cellFrame];
 
