@@ -214,6 +214,7 @@ static NSParagraphStyle	*defaultStyle = nil;
   if (defaultStyle == nil)
     {
       NSParagraphStyle	*style = [[self alloc] init];
+      /*
       int		i;
 
       for (i = 0; i < 12; i++)
@@ -225,6 +226,7 @@ static NSParagraphStyle	*defaultStyle = nil;
           [style->_tabStops addObject: tab];
           RELEASE(tab);
         }
+      */
       defaultStyle = style;
     }
   return defaultStyle;
@@ -306,6 +308,14 @@ static NSParagraphStyle	*defaultStyle = nil;
   return self;
 }
 
+- (NSString *)description
+{
+  return [NSString stringWithFormat: 
+                     @"%@ Alignment: %ld LineSpacing: %f ParagraphSpacing: %f LineBreakMode: %ld", 
+                   [super description], (long)_alignment, (float)_lineSpacing,
+                   (float)_paragraphSpacing, (long)_lineBreakMode];
+}
+
 /*
  *      "Leading": distance between the bottom of one line fragment and top
  *      of next (applied between lines in the same container).
@@ -464,7 +474,12 @@ static NSParagraphStyle	*defaultStyle = nil;
 {
   if ([aCoder allowsKeyedCoding])
     {
-      // TODO_NIB: Determine keys for NSParagraphStyle, if there are any.
+      _firstLineHeadIndent = [aCoder decodeFloatForKey: @"NSFirstLineHeadIndent"];
+      _headIndent = [aCoder decodeFloatForKey: @"NSHeadIndent"];
+      _paragraphSpacing = [aCoder decodeFloatForKey: @"NSParagraphSpacingBefore"];
+      ASSIGN(_tabStops, [aCoder decodeObjectForKey: @"NSTabStops"]);
+      ASSIGN(_textLists, [aCoder decodeObjectForKey: @"NSTextLists"]);
+      _baseDirection = [aCoder decodeIntForKey: @"NSWritingDirection"];
     }
   else
     {
@@ -530,7 +545,12 @@ static NSParagraphStyle	*defaultStyle = nil;
 {
   if ([aCoder allowsKeyedCoding])
     {
-      // TODO_NIB: Determine keys for NSParagraphStyle, if there are any.
+      [aCoder encodeFloat: _firstLineHeadIndent forKey: @"NSFirstLineHeadIndent"];
+      [aCoder encodeFloat: _headIndent forKey: @"NSHeadIndent"];
+      [aCoder encodeFloat: _paragraphSpacing forKey: @"NSParagraphSpacingBefore"];
+      [aCoder encodeObject: _tabStops forKey: @"NSTabStops"];
+      [aCoder encodeObject: _textLists forKey: @"NSTextLists"];
+      [aCoder encodeInt: _baseDirection forKey: @"NSWritingDirection"];
     }
   else
     {
