@@ -418,7 +418,7 @@ static NSMutableArray *screenArray = nil;
   [super dealloc];
 }
 
-- (float) userSpaceScaleFactor
+- (CGFloat) userSpaceScaleFactor
 {
   NSNumber *factor = [[NSUserDefaults standardUserDefaults]
 		       objectForKey: @"GSScaleFactor"];
@@ -443,6 +443,11 @@ static NSMutableArray *screenArray = nil;
     }
 }
 
+- (CGFloat) backingScaleFactor
+{
+  return 1.0;
+}
+
 @end
 
 
