@@ -162,6 +162,21 @@ static int __documentTag = 0;
     }
 }
 
++ (BOOL)isAutomaticTextReplacementEnabled
+{
+  return NO;
+}
+
++ (BOOL)isAutomaticDashSubstitutionEnabled
+{
+  return NO;
+}
+
++ (BOOL)isAutomaticQuoteSubstitutionEnabled
+{
+  return NO;
+}
+
 //
 // Making a Checker available 
 //
@@ -444,6 +459,16 @@ static int __documentTag = 0;
   return nil;
 }
 
+- (NSRange)checkGrammarOfString:(NSString *)stringToCheck
+		     startingAt:(NSInteger)startingOffset
+		       language:(NSString *)language
+		           wrap:(BOOL)wrapFlag
+	 inSpellDocumentWithTag:(NSInteger)tag
+			details:(NSArray **)details
+{
+  return NSMakeRange(NSNotFound, 0);
+}
+
 //
 // Setting the Language 
 //
